@@ -121,7 +121,7 @@ dzl_directory_reaper_add_glob (DzlDirectoryReaper *self,
     glob = "*";
 
   p.type = PATTERN_GLOB;
-  p.min_age = ABS (min_age);
+  p.min_age = min_age;
   p.glob.directory = g_object_ref (directory);
   p.glob.glob = g_strdup (glob);
 
@@ -139,7 +139,7 @@ dzl_directory_reaper_add_file (DzlDirectoryReaper *self,
   g_return_if_fail (G_IS_FILE (file));
 
   p.type = PATTERN_FILE;
-  p.min_age = ABS (min_age);
+  p.min_age = min_age;
   p.file.file = g_object_ref (file);
 
   g_array_append_val (self->patterns, p);
@@ -151,6 +151,18 @@ dzl_directory_reaper_new (void)
   return g_object_new (DZL_TYPE_DIRECTORY_REAPER, NULL);
 }
 
+static gboolean
+has_expired (guint64 mtime,
+             guint64 min_age)
+{
+  guint64 now = g_get_real_time () / G_USEC_PER_SEC;
+
+  if (now >= min_age)
+    return (now - min_age) >= mtime;
+
+  return FALSE;
+}
+
 static gboolean
 remove_directory_with_children (GFile         *file,
                                 GCancellable  *cancellable,
@@ -168,7 +180,6 @@ remove_directory_with_children (GFile         *file,
   g_debug ("Removing uri recursively \"%s\"", uri);
 
   enumerator = g_file_enumerate_children (file,
-                                          G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK","
                                           G_FILE_ATTRIBUTE_STANDARD_NAME","
                                           G_FILE_ATTRIBUTE_STANDARD_TYPE","
                                           G_FILE_ATTRIBUTE_TIME_MODIFIED,
@@ -190,10 +201,10 @@ remove_directory_with_children (GFile         *file,
   while (NULL != (infoptr = g_file_enumerator_next_file (enumerator, cancellable, &enum_error)))
     {
       g_autoptr(GFileInfo) info = infoptr;
-      g_autoptr(GFile) child = g_file_enumerator_get_child (enumerator, info);
-      GFileType file_type = g_file_info_get_file_type (info);
+      const gchar *name = g_file_info_get_name (info);
+      GFile *child = g_file_get_child (file, name);
 
-      if (!g_file_info_get_is_symlink (info) && file_type == G_FILE_TYPE_DIRECTORY)
+      if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY)
         {
           if (!remove_directory_with_children (child, cancellable, error))
             return FALSE;
@@ -222,7 +233,6 @@ dzl_directory_reaper_execute_worker (GTask        *task,
                                      GCancellable *cancellable)
 {
   GArray *patterns = task_data;
-  gint64 now = g_get_real_time ();
 
   g_assert (G_IS_TASK (task));
   g_assert (DZL_IS_DIRECTORY_REAPER (source_object));
@@ -257,10 +267,7 @@ dzl_directory_reaper_execute_worker (GTask        *task,
 
           v64 = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED);
 
-          /* mtime is in seconds */
-          v64 *= G_USEC_PER_SEC;
-
-          if (v64 < now - p->min_age)
+          if (has_expired (v64, p->min_age))
             {
               if (!g_file_delete (p->file.file, cancellable, &error))
                 g_warning ("%s", error->message);
@@ -279,9 +286,7 @@ dzl_directory_reaper_execute_worker (GTask        *task,
             }
 
           enumerator = g_file_enumerate_children (p->glob.directory,
-                                                  G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK","
                                                   G_FILE_ATTRIBUTE_STANDARD_NAME","
-                                                  G_FILE_ATTRIBUTE_STANDARD_TYPE","
                                                   G_FILE_ATTRIBUTE_TIME_MODIFIED,
                                                   G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
                                                   cancellable,
@@ -296,28 +301,17 @@ dzl_directory_reaper_execute_worker (GTask        *task,
 
           while (NULL != (info = g_file_enumerator_next_file (enumerator, cancellable, NULL)))
             {
+              const gchar *name;
+
+              name = g_file_info_get_name (info);
               v64 = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_TIME_MODIFIED);
 
-              /* mtime is in seconds */
-              v64 *= G_USEC_PER_SEC;
-
-              if (v64 < now - p->min_age)
+              if (has_expired (v64, p->min_age))
                 {
-                  g_autoptr(GFile) file = g_file_enumerator_get_child (enumerator, info);
-                  GFileType file_type = g_file_info_get_file_type (info);
+                  g_autoptr(GFile) file = g_file_get_child (p->glob.directory, name);
 
-                  if (g_file_info_get_is_symlink (info) || file_type != G_FILE_TYPE_DIRECTORY)
+                  if (g_file_query_file_type (file, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, cancellable) == G_FILE_TYPE_DIRECTORY)
                     {
-                      if (!g_file_delete (file, cancellable, &error))
-                        {
-                          g_warning ("%s", error->message);
-                          g_clear_error (&error);
-                        }
-                    }
-                  else
-                    {
-                      g_assert (file_type == G_FILE_TYPE_DIRECTORY);
-
                       if (!remove_directory_with_children (file, cancellable, &error) ||
                           !g_file_delete (file, cancellable, &error))
                         {
@@ -325,6 +319,11 @@ dzl_directory_reaper_execute_worker (GTask        *task,
                           g_clear_error (&error);
                         }
                     }
+                  else if (!g_file_delete (file, cancellable, &error))
+                    {
+                      g_warning ("%s", error->message);
+                      g_clear_error (&error);
+                    }
                 }
 
               g_clear_object (&info);
