@@ -20,17 +20,13 @@
 
 #include <glib/gi18n.h>
 
-#include "dzl-trie.h"
+#include "search/dzl-trie.h"
+#include "util/dzl-macros.h"
 
 #if defined(__LP64__) || defined(_WIN64)
 # define TRIE_64 1
 #endif
 
-#define STATIC_ASSERT(a)                              \
-   G_STMT_START {                                     \
-      G_GNUC_UNUSED gchar static_assert[(a)? 0 : -1]; \
-   } G_STMT_END
-
 /**
  * SECTION:trie
  * @title: DzlTrie
@@ -77,7 +73,7 @@ G_DEFINE_BOXED_TYPE (DzlTrie, dzl_trie, dzl_trie_ref, dzl_trie_unref)
  * @children: The children #DzlTrieNodeChunk or %NULL. If the chunk is
  *   inline the DzlTrieNode, then there will be fewer items.
  */
-#pragma pack(push, 1)
+DZL_ALIGNED_BEGIN(1)
 struct _DzlTrieNodeChunk
 {
    DzlTrieNodeChunk *next;
@@ -86,8 +82,7 @@ struct _DzlTrieNodeChunk
    guint             count : 8;
    guint8            keys[6];
    DzlTrieNode      *children[0];
-};
-#pragma pack(pop)
+} DZL_ALIGNED_END(1);
 
 /**
  * DzlTrieNode:
@@ -97,14 +92,13 @@ struct _DzlTrieNodeChunk
  * @chunk: The first chunk in the chain. Inline chunks have fewer children
  *    elements than extra allocated chunks so that they are cache aligned.
  */
-#pragma pack(push, 1)
+DZL_ALIGNED_BEGIN(1)
 struct _DzlTrieNode
 {
    DzlTrieNode      *parent;
    gpointer          value;
    DzlTrieNodeChunk  chunk;
-};
-#pragma pack(pop)
+} DZL_ALIGNED_END(1);
 
 /**
  * DzlTrie:
@@ -118,6 +112,20 @@ struct _DzlTrie
    DzlTrieNode    *root;
 };
 
+#ifdef TRIE_64
+  G_STATIC_ASSERT (sizeof(gpointer) == 8);
+  G_STATIC_ASSERT ((FIRST_CHUNK_KEYS-1) == 3);
+  G_STATIC_ASSERT (((FIRST_CHUNK_KEYS-1) * sizeof(gpointer)) == 24);
+  G_STATIC_ASSERT(sizeof(DzlTrieNode) == 32);
+  G_STATIC_ASSERT(sizeof(DzlTrieNodeChunk) == 16);
+#else
+  G_STATIC_ASSERT (sizeof(gpointer) == 4);
+  G_STATIC_ASSERT ((FIRST_CHUNK_KEYS-1) == 2);
+  G_STATIC_ASSERT (((FIRST_CHUNK_KEYS-1) * sizeof(gpointer)) == 8);
+  G_STATIC_ASSERT(sizeof(DzlTrieNode) == 20);
+  G_STATIC_ASSERT(sizeof(DzlTrieNodeChunk) == 12);
+#endif
+
 /**
  * dzl_trie_malloc0:
  * @trie: A #DzlTrie
@@ -267,16 +275,6 @@ dzl_trie_node_move_to_front (DzlTrieNode      *node,
    chunk->keys[idx] = first->keys[offset];
    chunk->children[idx] = first->children[offset];
 
-#ifdef TRIE_64
-   STATIC_ASSERT(sizeof(gpointer) == 8);
-   STATIC_ASSERT((FIRST_CHUNK_KEYS-1) == 3);
-   STATIC_ASSERT(((FIRST_CHUNK_KEYS-1) * sizeof(gpointer)) == 24);
-#else
-   STATIC_ASSERT(sizeof(gpointer) == 4);
-   STATIC_ASSERT((FIRST_CHUNK_KEYS-1) == 2);
-   STATIC_ASSERT(((FIRST_CHUNK_KEYS-1) * sizeof(gpointer)) == 8);
-#endif
-
    memmove(&first->keys[1], &first->keys[0], (FIRST_CHUNK_KEYS-1));
    memmove(&first->children[1], &first->children[0], (FIRST_CHUNK_KEYS-1) * sizeof(DzlTrieNode *));
 
@@ -489,14 +487,6 @@ dzl_trie_new (GDestroyNotify value_destroy)
 {
    DzlTrie *trie;
 
-#ifdef TRIE_64
-   STATIC_ASSERT(sizeof(DzlTrieNode) == 32);
-   STATIC_ASSERT(sizeof(DzlTrieNodeChunk) == 16);
-#else
-   STATIC_ASSERT(sizeof(DzlTrieNode) == 20);
-   STATIC_ASSERT(sizeof(DzlTrieNodeChunk) == 12);
-#endif
-
    trie = g_new0(DzlTrie, 1);
    trie->ref_count = 1;
    trie->root = dzl_trie_node_new(trie, NULL);
